# Free energy surface reconstruction
The objective of this library is to generate free energy surface from temperature accelerated methods like Temperatue Acclerated Molecular Dynamics (TAMD/d-AFED), Unified Free Energy Dynamics (UFED), Temperature Accelerated Sliced Sampling (TASS) and Solute Tempered Adibatic Free energy dynamics. 

### Installation and Usage

Free energy calculator can be simply installed using pip

To install it run:

```bash
    pip install .
```

To use UFEDMM in your own Python script or Jupyter notebook, import it as follows:

```python
    import fes_calculator
```





